@@ -333,6 +333,8 @@ std::string url_enc( std::string comp )
 // We keep a (global) list of files we have created, so we can delete them
 std::vector<std::string> tempfilelist;
 
+// Make a cf-config file, of the old type
+// can also produce a bad tag, when sesdir is empty
 void make_cf_config( std::string name,
                      std::string proxyhostname,
                      std::string sesdir,
@@ -343,6 +345,30 @@ void make_cf_config( std::string name,
     f << "# Created by the unit test for fileter_cproxy\n";
     f << "# Should have been deleted at the end of the tests\n\n";
     f << "proxyhostname: " << proxyhostname << "\n";
+    if (sesdir.empty())
+      f << "unknownBADTAG: This-should-throw-an-error \n";
+    else
+      f << "sessiondir: " << sesdir << "\n";
+    f << "cfengine: " << cfengine << "\n";
+    f.close();
+    tempfilelist.push_back(name);
+} // make_cf_config
+
+// Make a cf-config file of the new type, with http(s?)proxyprefix
+void make_new_cf_config( std::string name,
+                     std::string http,
+                     std::string https,
+                     std::string sesdir,
+                     std::string cfengine )
+{
+    std::ofstream f(name.c_str());
+    f << "# cproxy config file\n\n";
+    f << "# Created by the unit test for fileter_cproxy\n";
+    f << "# Should have been deleted at the end of the tests\n\n";
+    if(!http.empty())
+        f << "httpproxyprefix: " << http << "\n";
+    if(!https.empty())
+        f << "httpsproxyprefix: " << https << "\n";
     f << "sessiondir: " << sesdir << "\n";
     f << "cfengine: " << cfengine << "\n";
     f.close();
@@ -439,6 +465,81 @@ void remove_dump_dir( std::string dumpdir, bool force=false )
     rmdir( dumpdir.c_str() );
 } // remove_dump_dir
 
+///////////////////
+// test 0
+// test the reading of the cf-config, and such
+void test0(void)
+{
+    const char *conf = // a very simple config
+        "<?xml version='1.0'?>\n"
+        "<filter type='cproxy'>\n"
+        "  <debug>1</debug>\n"
+        "  <cfconfig>./cf-config.unittest.cfg</cfconfig>\n"
+        "</filter>";
+
+    // A cf-config file with unknown tags
+    // Bit silly test, since the prefix is actually optional.
+    make_cf_config("./cf-config.unittest.cfg", // config file to write
+                   "localhost:9036/",  // We do not actually require a path prefix
+                   "", // empty session directory triggers a bad tag
+                   "localhost:" CFENGINEPORT );  // cf-zserver
+    try {
+        mp::filter::CProxy *bad_cpx = make_filter( conf );
+        YAZ_CHECK (!"Did not throw an exception for a bad tag");
+    }
+    catch (std::exception & e) {
+        YAZ_CHECK ("got an exception as expected" );
+    }
+
+    // A cf-config file with a bad proxyprefix that can not be split
+    // Bit silly test, since the prefix is actually optional.
+    make_cf_config("./cf-config.unittest.cfg", // config file to write
+                   "/localhost:9036",  // Illegal url prefix, can not be split into host and path
+                   ".", // session directory
+                   "localhost:" CFENGINEPORT );  // cf-zserver
+    try {
+        mp::filter::CProxy *bad_cpx = make_filter( conf );
+        YAZ_CHECK (!"Did not throw an exception for a missing proxy prefix path");
+    }
+    catch (std::exception & e) {
+        YAZ_CHECK ("got an exception as expected" );
+    }
+
+    // A cf-config file with a bad proxy prefix (all numerical component)
+    // Those will get confused with the session number, so they are disallowed
+    // (actually, filter_cproxy will handle the just fine, but later a
+    // filter_rewrite may run into problems. The old cproxy disallowed this,
+    // so we do too)
+    // There is a piece of code to detect them, this is to test that piece.
+    make_cf_config("./cf-config.unittest.cfg", // config file to write
+                   "localhost:9036/XXX/2013",  // Illegal url prefix
+                   ".", // session directory
+                   "localhost:" CFENGINEPORT );  // cf-zserver
+    try {
+        mp::filter::CProxy *bad_cpx = make_filter( conf );
+        YAZ_CHECK (!"Did not throw an exception for a bad proxyprefix!");
+    }
+    catch (std::exception & e) {
+        YAZ_CHECK ("got an exception as expected" );
+    }
+
+    // A new-style cf-config file with conflicting proxy prefixes
+    make_new_cf_config("./cf-config.unittest.cfg", // config file to write
+                  "http://pxy.id.com/XXX",
+                  "https://pxy.id.com/ZZZ",
+                   ".", // session directory
+                   "localhost:" CFENGINEPORT );  // cf-zserver
+    try {
+        mp::filter::CProxy *bad_cpx = make_filter( conf );
+        YAZ_CHECK (!"Did not throw an exception for conflicting prefixes!");
+    }
+    catch (std::exception & e) {
+        YAZ_CHECK ("got an exception as expected" );
+    }
+
+}
+
+
 /////////////////////////
 // test 1
 // Things that can be tested directly against a filter_cproxy,
@@ -480,6 +581,10 @@ void test1(void)
         "    <value>Added by cproxy</value>\n"
         "  </addrequestheader>\n"
         "</filter>\n";
+
+
+
+    //
     make_cf_config("./cf-config.unittest.cfg", // config file to write
                    "localhost:9036/XXX/node102",  // url prefix
                    ".", // session directory
@@ -535,7 +640,7 @@ void test1(void)
     pack = process_url(cpx, "http://localhost:9036/XXX/cproxydebug-3/node102/"
                             "99/badsession.com/error.txt");
     YAZ_CHECK( check_response_code(pack, 400) );
-    YAZ_CHECK( check_response_content(pack, "Got session '99' "
+    YAZ_CHECK( check_response_content(pack, "Got session '99' proto 'http' "
                                  "host 'badsession.com' path 'error.txt'" ) );
     YAZ_CHECK( check_response_content(pack, "got sessionfilename './cf.99'" ) );
     YAZ_CHECK( check_response_content(pack,
@@ -566,6 +671,50 @@ void test1(void)
     YAZ_CHECK( check_no_request_header(pack,"X-MK-Component") );
     delete(pack);
 
+    // Existing session file, but pretty much emtpy. No cookies.
+    // New form url for HTTP
+    make_session_file( "." , "100",
+              "#pretty empty session file, huh\n");
+    pack = process_url(cpx, "http://localhost:9036/XXX/cproxydebug-7/node102/"
+                      "100/http/oksession.com/page.txt");
+    YAZ_CHECK( check_response_code(pack, 200) );
+    YAZ_CHECK( check_response_content(pack, "Got session '100'" ) );
+    YAZ_CHECK( check_response_content(pack, "got sessionfilename './cf.100'" ) );
+    YAZ_CHECK( check_response_content(pack, "Original request cookie line ''" ) );
+    YAZ_CHECK( check_response_content(pack, "Final cookie line: ''" ) );
+    YAZ_CHECK( check_no_request_header(pack, "Cookie") );
+    // Check that we pass the skiplink headers from the config
+    YAZ_CHECK( check_any_request_header(pack,"X-Metaproxy-SkipLink",
+                                        "skippage.com .*" ));
+    YAZ_CHECK( check_any_request_header(pack,"X-Metaproxy-SkipLink",
+                                        ".* skiplink.com" ));
+    YAZ_CHECK( check_any_request_header(pack,"X-Metaproxy-SkipLink",
+                                        "bothpage.com bothlink.com" ));
+    YAZ_CHECK( check_no_request_header(pack,"X-MK-Component") );
+    delete(pack);
+
+    // Existing session file, but pretty much emtpy. No cookies.
+    // New form url for HTTPS
+    make_session_file( "." , "100",
+              "#pretty empty session file, huh\n");
+    pack = process_url(cpx, "http://localhost:9036/XXX/cproxydebug-7/node102/"
+                      "100/http/oksession.com/page.txt");
+    YAZ_CHECK( check_response_code(pack, 200) );
+    YAZ_CHECK( check_response_content(pack, "Got session '100'" ) );
+    YAZ_CHECK( check_response_content(pack, "got sessionfilename './cf.100'" ) );
+    YAZ_CHECK( check_response_content(pack, "Original request cookie line ''" ) );
+    YAZ_CHECK( check_response_content(pack, "Final cookie line: ''" ) );
+    YAZ_CHECK( check_no_request_header(pack, "Cookie") );
+    // Check that we pass the skiplink headers from the config
+    YAZ_CHECK( check_any_request_header(pack,"X-Metaproxy-SkipLink",
+                                        "skippage.com .*" ));
+    YAZ_CHECK( check_any_request_header(pack,"X-Metaproxy-SkipLink",
+                                        ".* skiplink.com" ));
+    YAZ_CHECK( check_any_request_header(pack,"X-Metaproxy-SkipLink",
+                                        "bothpage.com bothlink.com" ));
+    YAZ_CHECK( check_no_request_header(pack,"X-MK-Component") );
+    delete(pack);
+
     // Existing session file, but pretty much emtpy.
     // URL contains another part that could be misunderstood for a
     // sessionid. Never been a problem here, but the rewrite filter got
@@ -584,6 +733,13 @@ void test1(void)
     YAZ_CHECK( check_response_code(pack, 200) );
     delete(pack);
 
+    // Full HTTPS URL in the GET line
+    pack = make_package("https://localhost:9036/XXX/cproxydebug-7/node102/"
+           "100/https/oksession.com/page.txt",1); // the 1 here makes it full URL
+    cpx->process(*pack);
+    YAZ_CHECK( check_response_code(pack, 200) );
+    delete(pack);
+
     // Url that contains a lowercase prefix
     // We have seen javascript that explictily lowercases whole URLs CPXY-64
     // Would be good if could enforce prefixes to be lowercase to begin with,
@@ -593,7 +749,7 @@ void test1(void)
     YAZ_CHECK( check_response_code(pack, 200) );
     delete(pack);
     
-    // Url that contains a bad prefix 
+    // Url that contains a bad prefix (or an invalid protocol)
     pack = process_url(cpx, "http://localhost:9036/XXX/cproxydebug-7/node102/"
     "/badprefix/100/oksession.com/2013/page.txt");
     YAZ_CHECK( check_response_code(pack, 400) );
@@ -649,13 +805,14 @@ void test1(void)
     add_request_header(pack, "Referer",
          "http://localhost:9036/XXX/node102/100/ref.host/ref.path");
     cpx->process(*pack);
-
     YAZ_CHECK( check_response_code(pack, 302) );
     YAZ_CHECK( check_response_header(pack, "Location",
                    "http://localhost:9036/XXX/node102/100/ref.host/page.txt") );
     YAZ_CHECK( check_response_header(pack,"X-MK-Component", " ") );
     delete(pack);
-    
+
+    // TODO - Test for referer headers with https:// and /https/
+
     // simple referer header with just a host name, no trailing slash
     pack = make_package("http://localhost:9036/cproxydebug-15/page.txt",0);
     // Must have the content-bit (8) in debug, or we fake a regular OK response
@@ -771,9 +928,12 @@ void test1(void)
 
     // More complex session. Now (as of 3.1.0) with new-form cookie lines.
     make_session_file( "." , "101",
+              " #Test 101\n"
+              "#\n"
+              "   # \n"
               "Referer http://www.indexdata.com/software/ \n"
               "Username someuser\n"
-              "Password secretpassword\n"
+              "Password secret#password\n"   // hash char in password is ok. CPXY-165
               "Proxyip 1.2.3.4\n"
               "Baseurl http://www.indexdata.com/somepage?with=two&params=x\n"
               "Set-Cookie one=ONE; domain = www.indexdata.com \n"
@@ -796,7 +956,7 @@ void test1(void)
     YAZ_CHECK( check_request_header(pack, "Referer","http://www.indexdata.com/software/") );
     YAZ_CHECK( check_request_header(pack, "X-Metaproxy-Proxy", "1.2.3.4") );
     YAZ_CHECK( check_request_header(pack, "Authorization",
-                                    "Basic c29tZXVzZXI6c2VjcmV0cGFzc3dvcmQ=") );
+                                    "Basic c29tZXVzZXI6c2VjcmV0I3Bhc3N3b3Jk") );
     YAZ_CHECK( check_any_request_header(pack,"X-Metaproxy-SkipLink",
                                         "skippage2.com skiplink2.com" ));
     YAZ_CHECK( check_request_header(pack, "X-MK-Component", " "));
@@ -914,7 +1074,7 @@ void test1(void)
     // But it should build a proper SRU request.
     make_param_file(".", "103",
                     "fake_content_connector",
-                    "user/passwd",
+                    "user/password#with-?/funny",  // CPXY-165
                     "1.2.3.4:80",
                     "testrealm",
                     "cfusername/cfpassword"
@@ -929,7 +1089,7 @@ void test1(void)
                 ",cproxysession=103"
                 "&realm=testrealm"
                 "&user=user"
-                "&password=passwd"
+                "&password=password%23with-%3F%2Ffunny"  // note url-encoding
                 "&proxy=1.2.3.4%3A80"    // note url-encoded :80
             "?version=1.2"
             "&operation=searchRetrieve"
@@ -993,25 +1153,6 @@ void test1(void)
     delete(pack);
 
 
-
-    // A cf-config file with a bad proxy prefix (all numerical component)
-    // Those will get confused with the session number, so they are disallowed
-    // (actually, filter_cproxy will handle the just fine, but later a
-    // filter_rewrite may run into problems. The old cproxy disallowed this,
-    // so we do too)
-    // There is a piece of code to detect them, this is to test that piece.
-    make_cf_config("./cf-config.unittest.cfg", // config file to write
-                   "localhost:9036/XXX/2013",  // Illegal url prefix
-                   ".", // session directory
-                   "localhost:" CFENGINEPORT );  // cf-zserver
-    try {
-        mp::filter::CProxy *bad_cpx = make_filter( conf );
-        YAZ_CHECK (!"Did not throw an exception for a bad proxyprefix!");
-    }
-    catch (std::exception & e) {
-        YAZ_CHECK ("got an exception as expected" );
-    }
-
     // Omitting some cookies
     // domains omit1 and omit2 come from the config, 3 and 4 from the session here
     // (note the \s between the method and the domain, that's a regexp space)
@@ -1086,7 +1227,8 @@ void test1(void)
 //  - filter_rewrite_html to deproxify the request and proxify resulting html
 //  - filter_file to serve static file(s)
 //  - Build static test files for filter_file to return
-
+//
+// TODO - Various https tests
 void test2 (void)
 {
     mp::Package *pack;
@@ -1096,7 +1238,7 @@ void test2 (void)
             ".", // session directory
             "" );  // cf-zserver for content connectors, "localhost:9001"
 
-// Comment out the following to log the packets in every between            
+// Comment out the following not to log the packets in every between
 #define LOG_ALL 1
             
     std::string conf =
@@ -1355,7 +1497,7 @@ void test2 (void)
        // since we are debugging
     YAZ_CHECK( check_response_content(pack, "<h1>test page</h1>" ) );
     YAZ_CHECK( check_response_content(pack,
-      "http://localhost:9036/YYY/ZZZ/200/www.a5.com/staff/page.html" ) );
+      "http://localhost:9036/YYY/ZZZ/200/http/www.a5.com/staff/page.html" ) );
     // the cproxysession cookie has the target host name, and the session number
     YAZ_CHECK( check_response_header(pack,"Set-Cookie",
                             "cproxysession=dummyhost.com/200; Path=/" ) );
@@ -1374,44 +1516,47 @@ void test2 (void)
     YAZ_CHECK( check_response_content(pack, "<h1>test page</h1>" ) );
 
     YAZ_CHECK( check_response_content(pack, 
-                 "\'http://localhost:9036/YYY/ZZZ/200/www.a1.com\'" ) );
+                 "\'http://localhost:9036/YYY/ZZZ/200/http/www.a1.com\'" ) );
     YAZ_CHECK( check_response_content(pack, 
-                 "\'http://localhost:9036/YYY/ZZZ/200/www.a2.com/\'" ) );
+                 "\'http://localhost:9036/YYY/ZZZ/200/http/www.a2.com/\'" ) );
     
     YAZ_CHECK( check_response_content(pack, 
-                 "'http://localhost:9036/YYY/ZZZ/200/www.a3.com/staff'" ) );
+                 "'http://localhost:9036/YYY/ZZZ/200/http/www.a3.com/staff'" ) );
     YAZ_CHECK( check_response_content(pack, 
-                 "http://localhost:9036/YYY/ZZZ/200/www.a4.com/staff/" ) );
+                 "http://localhost:9036/YYY/ZZZ/200/http/www.a4.com/staff/" ) );
     YAZ_CHECK( check_response_content(pack, 
-                 "http://localhost:9036/YYY/ZZZ/200/www.a5.com/staff/page.html" ) );
+                 "http://localhost:9036/YYY/ZZZ/200/http/www.a5.com/staff/page.html" ) );
     YAZ_CHECK( check_response_content(pack, 
-                 "http://localhost:9036/YYY/ZZZ/200/doubleslash.com/a6" ) );
+                 "http://localhost:9036/YYY/ZZZ/200/http/doubleslash.com/a6" ) );
 
     YAZ_CHECK( check_response_content(pack, 
-                 "http://localhost:9036/YYY/ZZZ/200/www.a7.com/uppercasetag" ) );
+                 "http://localhost:9036/YYY/ZZZ/200/http/www.a7.com/uppercasetag" ) );
     YAZ_CHECK( check_response_content(pack, 
                  "ftp://ftp.indexdata.com/pub/a8/file.gz" ) );
-    YAZ_CHECK( check_response_content(pack, "https://secure.indexdata.com/a9/" ) );
-        
+
+    //YAZ_CHECK( check_response_content(pack, "https://secure.indexdata.com/a9/" ) );
+    YAZ_CHECK( check_response_content(pack,
+                                      "http://localhost:9036/YYY/ZZZ/200/https/secure.indexdata.com/a9/" ) );
+
     YAZ_CHECK( check_response_content(pack, 
-                 "http://localhost:9036/YYY/ZZZ/200/www.a10.com/path/page.html" ) );
+                 "http://localhost:9036/YYY/ZZZ/200/http/www.a10.com/path/page.html" ) );
     
     // host-relative links
-    YAZ_CHECK( check_response_content(pack, "\'http://localhost:9036/YYY/ZZZ/200/dummyhost.com/\'" ) );
-    YAZ_CHECK( check_response_content(pack, "\'http://localhost:9036/YYY/ZZZ/200/dummyhost.com/h1\'" ) );
-    YAZ_CHECK( check_response_content(pack, "\'http://localhost:9036/YYY/ZZZ/200/dummyhost.com/h2/page\'" ) );
-    YAZ_CHECK( check_response_content(pack, "\'http://localhost:9036/YYY/ZZZ/200/dummyhost.com/h3/page/\'" ) );
-    YAZ_CHECK( check_response_content(pack, "\'http://localhost:9036/YYY/ZZZ/200/dummyhost.com/h4/page.html\'" ) );
+    YAZ_CHECK( check_response_content(pack, "\'http://localhost:9036/YYY/ZZZ/200/http/dummyhost.com/\'" ) );
+    YAZ_CHECK( check_response_content(pack, "\'http://localhost:9036/YYY/ZZZ/200/http/dummyhost.com/h1\'" ) );
+    YAZ_CHECK( check_response_content(pack, "\'http://localhost:9036/YYY/ZZZ/200/http/dummyhost.com/h2/page\'" ) );
+    YAZ_CHECK( check_response_content(pack, "\'http://localhost:9036/YYY/ZZZ/200/http/dummyhost.com/h3/page/\'" ) );
+    YAZ_CHECK( check_response_content(pack, "\'http://localhost:9036/YYY/ZZZ/200/http/dummyhost.com/h4/page.html\'" ) );
 
     // Check that the links in the text content are not changed
     YAZ_CHECK( check_response_content(pack, "http://www.p1.com " ) );
     YAZ_CHECK( check_response_content(pack, "http://www.p2.com/staff/page.html" ) );
 
     YAZ_CHECK( check_response_content(pack,
-           "url1=\"http://localhost:9036/YYY/ZZZ/200/url1.in.script\"" ) );
+           "url1=\"http://localhost:9036/YYY/ZZZ/200/http/url1.in.script\"" ) );
 
     YAZ_CHECK( check_response_content(pack,
-           "url3=\"http://localhost:9036/YYY/ZZZ/200/url3.in.script/page\"" ) );
+           "url3=\"http://localhost:9036/YYY/ZZZ/200/http/url3.in.script/page\"" ) );
 
     // We can not proxify host-relative links, any string that starts with a '/'
     // would look like one, and could be something totally different, like an XPath
@@ -1422,12 +1567,12 @@ void test2 (void)
     YAZ_CHECK( check_response_content(pack, "hostrel5=\"/hr5/page.html\"" ) );
     
     YAZ_CHECK( check_response_content(pack, "http://unquoted.com" ) );
-    YAZ_CHECK( check_response_content(pack, "http://localhost:9036/YYY/ZZZ/200/singlequoted.com" ) );
-    YAZ_CHECK( check_response_content(pack, "http://localhost:9036/YYY/ZZZ/200/doublequoted.com" ) );
-    YAZ_CHECK( check_response_content(pack, "http://localhost:9036/YYY/ZZZ/200/mixedquoted1.com" ) );
-    YAZ_CHECK( check_response_content(pack, "http://localhost:9036/YYY/ZZZ/200/mixedquoted2.com" ) );
+    YAZ_CHECK( check_response_content(pack, "http://localhost:9036/YYY/ZZZ/200/http/singlequoted.com" ) );
+    YAZ_CHECK( check_response_content(pack, "http://localhost:9036/YYY/ZZZ/200/http/doublequoted.com" ) );
+    YAZ_CHECK( check_response_content(pack, "http://localhost:9036/YYY/ZZZ/200/http/mixedquoted1.com" ) );
+    YAZ_CHECK( check_response_content(pack, "http://localhost:9036/YYY/ZZZ/200/http/mixedquoted2.com" ) );
     YAZ_CHECK( check_response_content(pack, "http://outcommented.com" ) );
-    YAZ_CHECK( check_response_content(pack, "http://localhost:9036/YYY/ZZZ/200/write.com" ) );
+    YAZ_CHECK( check_response_content(pack, "http://localhost:9036/YYY/ZZZ/200/http/write.com" ) );
       // See MP-486
     YAZ_CHECK( check_response_content(pack, "if(a<b)" ) );
     YAZ_CHECK( check_response_content(pack, "document.write(\"</script\" + \">\")" ) );
@@ -1439,9 +1584,9 @@ void test2 (void)
     YAZ_CHECK( check_response_content(pack, "<a href=/unquoted >unquoted</a>" ) );
 
     YAZ_CHECK( check_response_content(pack,
-        "onclick=\"window.location='http://localhost:9036/YYY/ZZZ/200/first.com';" ) );
+        "onclick=\"window.location='http://localhost:9036/YYY/ZZZ/200/http/first.com';" ) );
     YAZ_CHECK( check_response_content(pack,
-        "onclick=\'window.location=\"http://localhost:9036/YYY/ZZZ/200/second.com\";" ) );
+        "onclick=\'window.location=\"http://localhost:9036/YYY/ZZZ/200/http/second.com\";" ) );
 
     // test for CPXY-47, require at least something in the host portion
     // Have seen such construct in real life.
@@ -1572,7 +1717,7 @@ void test2 (void)
     // Link headers are special, they have <>'s around the URL, and thus need
     // their own rules.
     YAZ_CHECK( check_response_header(pack,"Link",
-                 "<http://localhost:9036/YYY/ZZZ/200/see.also.com/absolute/>;") );
+                 "<http://localhost:9036/YYY/ZZZ/200/http/see.also.com/absolute/>;") );
     YAZ_CHECK( check_any_response_header(pack,"Link", "<relative/path/>;"));
     YAZ_CHECK( check_any_response_header(pack,"Link",
       "<http://localhost:9036/YYY/ZZZ/200/sub.dummydomain.com/host/relative/>;") );
@@ -1728,7 +1873,7 @@ void test2 (void)
     YAZ_CHECK( check_response_code(pack, 301) );
     YAZ_CHECK( check_no_response_header(pack,"Content-Type") );
     YAZ_CHECK( check_response_header(pack,"Location", 
-                   "http://localhost:9036/YYY/ZZZ/200/www.newlocation.com/") );
+                   "http://localhost:9036/YYY/ZZZ/200/http/www.newlocation.com/") );
     delete(pack);
 
     std::string movedpage2 =
@@ -1749,7 +1894,7 @@ void test2 (void)
     YAZ_CHECK( check_response_code(pack, 302) );
     YAZ_CHECK( check_no_response_header(pack,"Content-Type") );
     YAZ_CHECK( check_response_header(pack,"Location",
-                "http://localhost:9036/YYY/ZZZ/200/"
+                "http://localhost:9036/YYY/ZZZ/200/http/"
                 "dummyhost.com/host/relative/link?with=params") );
     delete(pack);
 
@@ -1766,10 +1911,10 @@ void test2 (void)
     "YYY/ZZZ/200/"
     "dummyhost.com/rawtestfile/movedfile3",0);
     pack->router(router).move();
-    YAZ_CHECK( check_response_code(pack, 400) );
+    //YAZ_CHECK( check_response_code(pack, 400) );
+    // TODO - Now we can redirect to https, make proper tests
     delete(pack);
 
-
      
     // Test that the package can get to the bounce filter, and that the request
     // is properly deproxified at that point.
@@ -1828,6 +1973,7 @@ int main (int argc, char **argv)
     remove_dump_dir( "./cf.102.dump", true );
     remove_dump_dir( "./cf.200.dump", true );
     try {
+        test0();
         test1();
         test2();
     }
